@@ -1,8 +1,15 @@
+/*
+ SPDX-FileCopyrightText: 2005 Tobias Koenig <tokoe@kde.org>
+
+ SPDX-License-Identifier: MIT
+*/
+
 #include "converter.h"
-#include <code_generation/style.h>
+#include "elementargumentserializer.h"
 #include "settings.h"
-#include <QDebug>
 #include <QCoreApplication>
+#include <QDebug>
+#include <code_generation/style.h>
 
 using namespace KWSDL;
 
@@ -23,8 +30,9 @@ static Part::List selectedParts(const Binding &binding, const Message &message,
         const QString selectedPart = input ? op.input().part() : op.output().part();
         if (!selectedPart.isEmpty()) {
             Part::List selected;
-            Q_FOREACH (const Part &part, message.parts()) {
-                if (part.name() == selectedPart) {   // support for <soap:body parts="MoveFolderResult"/> (msexchange)
+            const Part::List parts = message.parts();
+            for (const Part &part : parts) {
+                if (part.name() == selectedPart) { // support for <soap:body parts="MoveFolderResult"/> (msexchange)
                     selected << part;
                 }
             }
@@ -67,13 +75,14 @@ static SoapBinding::Headers getOutputHeaders(const Binding &binding, const QStri
 bool Converter::convertClientService()
 {
     KODE::Class::List bindingClasses;
-    Q_FOREACH (const Service &service, mWSDL.definitions().services()) {
+    const Service::List services = mWSDL.definitions().services();
+    for (const Service &service : services) {
         Q_ASSERT(!service.name().isEmpty());
 
         QSet<QName> uniqueBindings = mWSDL.uniqueBindings(service);
-        //qDebug() << "Looking at" << service.name() << uniqueBindings;
+        // qDebug() << "Looking at" << service.name() << uniqueBindings;
 
-        Q_FOREACH (const QName &bindingName, uniqueBindings) {
+        for (const QName &bindingName : qAsConst(uniqueBindings)) {
             const Binding binding = mWSDL.findBinding(bindingName);
 
             QString className = KODE::Style::className(service.name());
@@ -132,6 +141,7 @@ bool Converter::convertClientService()
                 KODE::Function ctor(newClass.name());
                 ctor.addArgument(KODE::Function::Argument(QLatin1String("QObject* _parent"), QLatin1String("nullptr")));
                 ctor.addInitializer(QLatin1String("QObject(_parent)"));
+                ctor.setExplicit(true);
                 KODE::Function dtor(QLatin1Char('~') + newClass.name());
                 KODE::Code ctorCode, dtorCode;
 
@@ -176,7 +186,7 @@ bool Converter::convertClientService()
                 getEndPoint.setDocs(QLatin1String("Return the end point that will be used."));
                 newClass.addFunction(getEndPoint);
             }
-            //setSoapVersion() method
+            // setSoapVersion() method
             {
                 KODE::Function setSoapVersion(QLatin1String("setSoapVersion"), QLatin1String("void"));
                 setSoapVersion.addArgument(QLatin1String("KDSoapClientInterface::SoapVersion soapVersion"));
@@ -187,7 +197,7 @@ bool Converter::convertClientService()
                                                      "version can be KDSoapClientInterface::SOAP1_1 or KDSoapClientInterface::SOAP1_2"));
                 newClass.addFunction(setSoapVersion);
             }
-            //soapVersion() method
+            // soapVersion() method
             {
                 KODE::Function getSoapVersion(QLatin1String("soapVersion"), QLatin1String("KDSoapClientInterface::SoapVersion"));
                 getSoapVersion.setConst(true);
@@ -239,12 +249,14 @@ bool Converter::convertClientService()
                 lastError.setDocs(QLatin1String("Return the error from the last blocking call.\nEmpty if no error."));
                 newClass.addFunction(lastError);
             }
-            //soapError() signal
+            // soapError() signal
             {
                 KODE::Function errorSignal(QLatin1String("soapError"), QLatin1String("void"), KODE::Function::Signal);
                 errorSignal.addArgument(QLatin1String("const QString& method"));
                 errorSignal.addArgument(QLatin1String("const KDSoapMessage& fault"));
-                errorSignal.setDocs(QLatin1String("This signal is emitted whenever a SOAP call failed, for a central processing of all SOAP errors.\nmethod is the name of the method (or operation) that returned the fault, for instance \"addContact\"."));
+                errorSignal.setDocs(
+                    QLatin1String("This signal is emitted whenever a SOAP call failed, for a central processing of all SOAP errors.\nmethod is the "
+                                  "name of the method (or operation) that returned the fault, for instance \"addContact\"."));
                 newClass.addFunction(errorSignal);
             }
 
@@ -263,14 +275,17 @@ bool Converter::convertClientService()
 
             // clientInterface() methods
             {
-                KODE::Function clientInterface(QLatin1String("clientInterface"), QLatin1String("const KDSoapClientInterface*"), KODE::Function::Public);
+                KODE::Function clientInterface(QLatin1String("clientInterface"), QLatin1String("const KDSoapClientInterface*"),
+                                               KODE::Function::Public);
                 clientInterface.setConst(true);
                 KODE::Code code;
                 code += "if (!d_ptr->m_clientInterface) {";
                 code.indent();
                 const QByteArray encoded = webserviceLocation.toEncoded();
-                code += QLatin1String("const QString endPoint = !d_ptr->m_endPoint.isEmpty() ? d_ptr->m_endPoint : QString::fromLatin1(\"") + QString::fromLatin1(encoded.data(), encoded.size()) + QLatin1String("\");");
-                code += QLatin1String("const QString messageNamespace = QString::fromLatin1(\"") + mWSDL.definitions().targetNamespace() + QLatin1String("\");");
+                code += QLatin1String("const QString endPoint = !d_ptr->m_endPoint.isEmpty() ? d_ptr->m_endPoint : QString::fromLatin1(\"")
+                    + QString::fromLatin1(encoded.data(), encoded.size()) + QLatin1String("\");");
+                code += QLatin1String("const QString messageNamespace = QString::fromLatin1(\"") + mWSDL.definitions().targetNamespace()
+                    + QLatin1String("\");");
                 code += "d_ptr->m_clientInterface = new KDSoapClientInterface(endPoint, messageNamespace);";
                 if (soapStyle(binding) == SoapBinding::DocumentStyle) {
                     code += "d_ptr->m_clientInterface->setStyle( KDSoapClientInterface::DocumentStyle );";
@@ -284,13 +299,16 @@ bool Converter::convertClientService()
                 code += "}";
                 code += "return d_ptr->m_clientInterface;";
                 clientInterface.setBody(code);
-                clientInterface.setDocs(QLatin1String("Returns the underlying KDSoapClientInterface instance, which allows to access setCookieJar, lastResponseHeaders, etc."));
+                clientInterface.setDocs(QLatin1String(
+                    "Returns the underlying KDSoapClientInterface instance, which allows to access setCookieJar, lastResponseHeaders, etc."));
                 newClass.addFunction(clientInterface);
             }
             {
-                KODE::Function mutableClientInterface(QLatin1String("clientInterface"), QLatin1String("KDSoapClientInterface*"), KODE::Function::Public);
+                KODE::Function mutableClientInterface(QLatin1String("clientInterface"), QLatin1String("KDSoapClientInterface*"),
+                                                      KODE::Function::Public);
                 KODE::Code code;
-                code += QLatin1String("return const_cast<KDSoapClientInterface*>( const_cast< const ") + newClass.name() + QLatin1String("*>( this )->clientInterface() );");
+                code += QLatin1String("return const_cast<KDSoapClientInterface*>( const_cast< const ") + newClass.name()
+                    + QLatin1String("*>( this )->clientInterface() );");
                 mutableClientInterface.setBody(code);
                 newClass.addFunction(mutableClientInterface);
             }
@@ -298,9 +316,9 @@ bool Converter::convertClientService()
             SoapBinding::Headers soapHeaders;
 
             PortType portType = mWSDL.findPortType(binding.portTypeName());
-            //qDebug() << portType.name();
+            // qDebug() << portType.name();
             const Operation::List operations = portType.operations();
-            Q_FOREACH (const Operation &operation, operations) {
+            for (const Operation &operation : operations) {
                 Operation::OperationType opType = operation.operationType();
                 switch (opType) {
                 case Operation::OneWayOperation:
@@ -334,14 +352,15 @@ bool Converter::convertClientService()
                 }
 
                 // Collect message parts used as headers
-                Q_FOREACH (const SoapBinding::Header &header, getInputHeaders(binding, operation.name())) {
+                const SoapBinding::Headers inputHeaders = getInputHeaders(binding, operation.name());
+                for (const SoapBinding::Header &header : inputHeaders) {
                     if (!soapHeaders.contains(header)) {
                         soapHeaders.append(header);
                     }
                 }
             } // end of for each operation
 
-            Q_FOREACH (const SoapBinding::Header &header, soapHeaders) {
+            for (const SoapBinding::Header &header : qAsConst(soapHeaders)) {
                 createHeader(header, newClass);
             }
             bindingClasses.append(newClass);
@@ -355,7 +374,7 @@ bool Converter::convertClientService()
                 }
 
                 // for each operation, create a job class
-                Q_FOREACH (const Operation &operation, operations) {
+                for (const Operation &operation : qAsConst(operations)) {
                     Operation::OperationType opType = operation.operationType();
                     if (opType != Operation::SolicitResponseOperation && opType != Operation::RequestResponseOperation) {
                         continue;
@@ -380,11 +399,12 @@ bool Converter::convertClientService()
                     KODE::Function ctor(jobClass.name());
                     ctor.addArgument(KODE::Function::Argument(QString::fromLatin1("%1* service").arg(fullyQualified(newClass))));
                     ctor.addArgument(KODE::Function::Argument(QLatin1String("QObject* _parent"), QLatin1String("nullptr")));
+                    ctor.setExplicit(true);
                     ctor.addInitializer(QLatin1String("KDSoapJob(_parent)"));
                     ctor.addInitializer(QLatin1String("mService(service)"));
 
                     const Message message = mWSDL.findMessage(operation.input().message());
-                    Q_FOREACH (const Part &part, selectedParts(binding, message, operation, true /*input*/)) {
+                    for (const Part &part : selectedParts(binding, message, operation, true /*input*/)) {
                         const QString partName = part.name();
                         ctor.addInitializer(KODE::MemberVariable::memberVariableName(partName) + "()");
                         jobClass.addHeaderIncludes(mTypeMap.headerIncludes(part.type()));
@@ -392,7 +412,7 @@ bool Converter::convertClientService()
 
                     const Message outputMsg = mWSDL.findMessage(operation.output().message());
 
-                    Q_FOREACH (const Part &part, selectedParts(binding, outputMsg, operation, false /*output*/)) {
+                    for (const Part &part : selectedParts(binding, outputMsg, operation, false /*output*/)) {
                         const QString varName = mNameMapper.escape(QLatin1String("result") + upperlize(part.name()));
                         ctor.addInitializer(KODE::MemberVariable::memberVariableName(varName) + "()");
                         jobClass.addHeaderIncludes(mTypeMap.headerIncludes(part.type()));
@@ -402,7 +422,7 @@ bool Converter::convertClientService()
 
                     QStringList inputGetters;
 
-                    Q_FOREACH (const Part &part, selectedParts(binding, message, operation, true /*input*/)) {
+                    for (const Part &part : selectedParts(binding, message, operation, true /*input*/)) {
                         const QString varType = mTypeMap.localType(part.type(), part.element());
                         const KODE::MemberVariable member(part.name(), varType);
                         jobClass.addMemberVariable(member);
@@ -430,7 +450,9 @@ bool Converter::convertClientService()
                     const bool hasAction = clientAddAction(doStartCode, binding, operationName);
                     clientGenerateMessage(doStartCode, binding, message, operation, /*use members=*/true);
 
-                    QString callLine = QString::fromLatin1("KDSoapPendingCall pendingCall = mService->clientInterface()->asyncCall(QLatin1String(\"%1\"), message").arg(operationName);
+                    QString callLine =
+                        QString::fromLatin1("KDSoapPendingCall pendingCall = mService->clientInterface()->asyncCall(QLatin1String(\"%1\"), message")
+                            .arg(operationName);
                     if (hasAction) {
                         callLine += QLatin1String(", action");
                     }
@@ -439,8 +461,9 @@ bool Converter::convertClientService()
                     doStartCode += callLine;
 
                     doStartCode += "KDSoapPendingCallWatcher *watcher = new KDSoapPendingCallWatcher(pendingCall, this);";
-                    doStartCode += "QObject::connect(watcher, SIGNAL(finished(KDSoapPendingCallWatcher*)),\n"
-                                   "                 this, SLOT(slotFinished(KDSoapPendingCallWatcher*)));";
+                    doStartCode += "QObject::connect(watcher, &KDSoapPendingCallWatcher::finished,\n"
+                                   "                 this, &"
+                        + jobClass.name() + "::slotFinished);";
                     doStart.setBody(doStartCode);
                     jobClass.addFunction(doStart);
 
@@ -471,15 +494,16 @@ bool Converter::convertClientService()
                                 slotCode += QLatin1String("_reply = _reply.childValues().at(0);") + COMMENT;
                             }
 
-                            Q_FOREACH (const Part &part, outputParts) {
+                            for (const Part &part : qAsConst(outputParts)) {
                                 const QString varName = mNameMapper.escape(QLatin1String("result") + upperlize(part.name()));
                                 const KODE::MemberVariable member(varName, QString());
-                                slotCode.addBlock(deserializeRetVal(part, QLatin1String("_reply"), mTypeMap.localType(part.type(), part.element()), member.name()));
+                                slotCode.addBlock(
+                                    deserializeRetVal(part, QLatin1String("_reply"), mTypeMap.localType(part.type(), part.element()), member.name()));
 
                                 addJobResultMember(jobClass, part, varName, inputGetters);
                             }
                         }
-                        Q_FOREACH (const SoapBinding::Header &header, outputHeaders) {
+                        for (const SoapBinding::Header &header : qAsConst(outputHeaders)) {
                             const QName messageName = header.message();
                             const QString partName = header.part();
                             const Message message = mWSDL.findMessage(messageName);
@@ -487,7 +511,9 @@ bool Converter::convertClientService()
 
                             const QString varName = QLatin1String("resultHeader") + upperlize(part.name());
                             const KODE::MemberVariable member(varName, QString());
-                            const QString getHeader = QString::fromLatin1("watcher->returnHeaders().header(QLatin1String(\"%1\"), QLatin1String(\"%2\"))").arg(part.element().localName(), part.element().nameSpace());
+                            const QString getHeader =
+                                QString::fromLatin1("watcher->returnHeaders().header(QLatin1String(\"%1\"), QLatin1String(\"%2\"))")
+                                    .arg(part.element().localName(), part.element().nameSpace());
                             slotCode.addBlock(deserializeRetVal(part, getHeader, mTypeMap.localType(part.type(), part.element()), member.name()));
                             addJobResultMember(jobClass, part, varName, inputGetters);
                         }
@@ -523,10 +549,10 @@ void Converter::clientAddOneArgument(KODE::Function &callFunc, const Part &part,
 {
     const QString lowerName = lowerlize(part.name());
     const QString argType = mTypeMap.localInputType(part.type(), part.element());
-    //qDebug() << "localInputType" << part.type().qname() << part.element().qname() << "->" << argType;
+    // qDebug() << "localInputType" << part.type().qname() << part.element().qname() << "->" << argType;
     if (argType != QLatin1String("void")) {
         QString def;
-        if (part.type().isEmpty()) {   // element (document style)
+        if (part.type().isEmpty()) { // element (document style)
             // If the complex type is empty, we need it for serialization,
             // but we don't need the app to see it, so give it a default value.
             // Example:
@@ -535,7 +561,7 @@ void Converter::clientAddOneArgument(KODE::Function &callFunc, const Part &part,
             const XSD::ComplexType ctype = mWSDL.findComplexType(element.type());
             if (!ctype.isNull() && ctype.isEmpty()) {
                 def = mTypeMap.localType(part.type(), part.element()) + QLatin1String("()");
-                //def += "/* " + element.type().qname() + " is empty */";
+                // def += "/* " + element.type().qname() + " is empty */";
             }
         }
 
@@ -545,10 +571,11 @@ void Converter::clientAddOneArgument(KODE::Function &callFunc, const Part &part,
     newClass.addHeaderIncludes(mTypeMap.headerIncludes(part.type()));
 }
 
-void Converter::clientAddArguments(KODE::Function &callFunc, const Message &message, KODE::Class &newClass, const Operation &operation, const Binding &binding)
+void Converter::clientAddArguments(KODE::Function &callFunc, const Message &message, KODE::Class &newClass, const Operation &operation,
+                                   const Binding &binding)
 {
     const Part::List parts = selectedParts(binding, message, operation, true /*input*/);
-    Q_FOREACH (const Part &part, parts) {
+    for (const Part &part : parts) {
         clientAddOneArgument(callFunc, part, newClass);
     }
 }
@@ -581,22 +608,26 @@ QName Converter::elementNameForPart(const Part &part, bool *qualified, bool *nil
     }
 }
 
-void Converter::addMessageArgument(KODE::Code &code, const SoapBinding::Style &bindingStyle, const Part &part, const QString &localVariableName, const QByteArray &messageName, bool varIsMember)
+void Converter::addMessageArgument(KODE::Code &code, const SoapBinding::Style &bindingStyle, const Part &part, const QString &localVariableName,
+                                   const QByteArray &messageName, bool varIsMember)
 {
-    const QString partname = varIsMember ? QLatin1Char('m') + upperlize(localVariableName) : mNameMapper.escape(lowerlize(localVariableName));
+    const QString partname =
+        varIsMember ? KODE::MemberVariable::memberVariableName(localVariableName) : mNameMapper.escape(lowerlize(localVariableName));
+    const QString nilPartname = varIsMember ? KODE::MemberVariable::memberVariableName(localVariableName + "_nil") : partname + "_nil";
     // In document style, the "part" is directly added as arguments
     // See https://www.ibm.com/developerworks/webservices/library/ws-whichwsdl/
     if (bindingStyle == SoapBinding::DocumentStyle) {
-        code.addBlock(serializePart(part, partname, messageName, false));
+        code.addBlock(serializePart(part, partname, nilPartname, messageName, false));
     } else {
         const QString argType = mTypeMap.localType(part.type(), part.element());
         if (argType != QLatin1String("void")) {
-            code.addBlock(serializePart(part, partname, messageName + ".childValues()", true));
+            code.addBlock(serializePart(part, partname, nilPartname, messageName + ".childValues()", true));
         }
     }
 }
 
-void Converter::clientGenerateMessage(KODE::Code &code, const Binding &binding, const Message &message, const Operation &operation, bool varsAreMembers)
+void Converter::clientGenerateMessage(KODE::Code &code, const Binding &binding, const Message &message, const Operation &operation,
+                                      bool varsAreMembers)
 {
     code += "KDSoapMessage message;";
 
@@ -608,7 +639,7 @@ void Converter::clientGenerateMessage(KODE::Code &code, const Binding &binding,
         } else {
             code += "message.setUse(KDSoapMessage::LiteralUse);";
         }
-        //qDebug() << "input headers:" << op.inputHeaders().count();
+        // qDebug() << "input headers:" << op.inputHeaders().count();
 
         if (!op.input().nameSpace().isEmpty()) {
             code += "message.setNamespaceUri(QString::fromLatin1(\"" + op.input().nameSpace() + "\"));";
@@ -617,13 +648,14 @@ void Converter::clientGenerateMessage(KODE::Code &code, const Binding &binding,
 
     bool isBuiltin = false;
 
-    Q_FOREACH (const Part &part, selectedParts(binding, message, operation, true /*input*/)) {
+    for (const Part &part : selectedParts(binding, message, operation, true /*input*/)) {
         isBuiltin = isBuiltin || mTypeMap.isBuiltinType(part.type(), part.element());
         addMessageArgument(code, soapStyle(binding), part, part.name(), "message", varsAreMembers);
     }
 
     if (soapStyle(binding) == SoapBinding::DocumentStyle && message.parts().size() > 1 && isBuiltin) {
-        qWarning("A Document style cannot be formed with multiple parts of builtin type (eg : multiple parts xsd:string), please correct your WSDL file");
+        qWarning(
+            "A Document style cannot be formed with multiple parts of builtin type (eg : multiple parts xsd:string), please correct your WSDL file");
     }
 }
 
@@ -639,7 +671,8 @@ KODE::Code Converter::deserializeRetVal(const KWSDL::Part &part, const QString &
     const bool isComplex = mTypeMap.isComplexType(part.type(), part.element());
     const bool isPolymorphic = mTypeMap.isPolymorphic(part.type(), part.element());
     if (isBuiltin) {
-        code += varName + QLatin1String(" = ") + mTypeMap.deserializeBuiltin(part.type(), part.element(), replyMsgName, qtRetType) + QLatin1String(";") + COMMENT;
+        code += varName + QLatin1String(" = ") + mTypeMap.deserializeBuiltin(part.type(), part.element(), replyMsgName, qtRetType)
+            + QLatin1String(";") + COMMENT;
     } else if (isComplex) {
         const QString op = isPolymorphic ? "->" : ".";
         code += varName + op + QLatin1String("deserialize(") + replyMsgName + QLatin1String(");") + COMMENT;
@@ -665,7 +698,8 @@ bool Converter::convertClientCall(const Operation &operation, const Binding &bin
     KODE::Code code;
     const bool hasAction = clientAddAction(code, binding, operation.name());
     clientGenerateMessage(code, binding, inputMessage, operation);
-    QString callLine = QLatin1String("d_ptr->m_lastReply = clientInterface()->call(QLatin1String(\"") + operation.name() + QLatin1String("\"), message");
+    QString callLine =
+        QLatin1String("d_ptr->m_lastReply = clientInterface()->call(QLatin1String(\"") + operation.name() + QLatin1String("\"), message");
     if (hasAction) {
         callLine += QLatin1String(", action");
     }
@@ -710,7 +744,8 @@ bool Converter::convertClientCall(const Operation &operation, const Binding &bin
 
                 code += retType + QLatin1String(" ret;"); // local var
                 code += QLatin1String("const KDSoapValue val = d_ptr->m_lastReply.childValues().at(0);") + COMMENT;
-                code += demarshalVar(retPart.type(), retPart.element(), QLatin1String("ret"), retType, "val", false, false);
+                ElementArgumentSerializer serializer(mTypeMap, retPart.type(), retPart.element(), QLatin1String("ret"), QString());
+                code += serializer.demarshalVariable("val");
                 code += "return ret;";
             }
         }
@@ -724,7 +759,7 @@ bool Converter::convertClientCall(const Operation &operation, const Binding &bin
         code.unindent();
         Q_ASSERT(soapStyle(binding) == SoapBinding::DocumentStyle); // RPC with multiple return values? impossible, we generate a single wrapper
 
-        Q_FOREACH (const Part &part, outParts) {
+        for (const Part &part : qAsConst(outParts)) {
             const QString argType = mTypeMap.localType(part.type(), part.element());
             Q_ASSERT(!argType.isEmpty());
             const QString lowerName = lowerlize(part.name());
@@ -743,46 +778,46 @@ bool Converter::convertClientCall(const Operation &operation, const Binding &bin
 }
 
 // Generate async call method
-void Converter::convertClientInputMessage(const Operation &operation,
-        const Binding &binding, KODE::Class &newClass)
+void Converter::convertClientInputMessage(const Operation &operation, const Binding &binding, KODE::Class &newClass)
 {
     QString operationName = operation.name();
     KODE::Function asyncFunc(QLatin1String("async") + upperlize(operationName), QLatin1String("void"), KODE::Function::Public);
     asyncFunc.setDocs(QString::fromLatin1("Asynchronous call to %1.\n"
                                           "Remember to connect to %2 and %3.\n"
                                           "Deprecated, use %4 instead.")
-                      .arg(operation.name())
-                      .arg(lowerlize(operationName) + QLatin1String("Done"))
-                      .arg(lowerlize(operationName) + QLatin1String("Error"))
-                      .arg(upperlize(operationName) + QLatin1String("Job")));
+                          .arg(operation.name())
+                          .arg(lowerlize(operationName) + QLatin1String("Done"))
+                          .arg(lowerlize(operationName) + QLatin1String("Error"))
+                          .arg(upperlize(operationName) + QLatin1String("Job")));
     const Message message = mWSDL.findMessage(operation.input().message());
     clientAddArguments(asyncFunc, message, newClass, operation, binding);
     KODE::Code code;
     const bool hasAction = clientAddAction(code, binding, operation.name());
     clientGenerateMessage(code, binding, message, operation);
 
-    QString callLine = QLatin1String("KDSoapPendingCall pendingCall = clientInterface()->asyncCall(QLatin1String(\"") + operationName + QLatin1String("\"), message");
+    QString callLine = QLatin1String("KDSoapPendingCall pendingCall = clientInterface()->asyncCall(QLatin1String(\"") + operationName
+        + QLatin1String("\"), message");
     if (hasAction) {
         callLine += QLatin1String(", action");
     }
     callLine += QLatin1String(");");
     code += callLine;
 
-    if (operation.operationType() == Operation::RequestResponseOperation ||
-            operation.operationType() == Operation::OneWayOperation) {
+    if (operation.operationType() == Operation::RequestResponseOperation || operation.operationType() == Operation::OneWayOperation) {
         const QString finishedSlotName = QLatin1String("_kd_slot") + upperlize(operationName) + QLatin1String("Finished");
 
         code += "KDSoapPendingCallWatcher *watcher = new KDSoapPendingCallWatcher(pendingCall, this);";
-        code += QLatin1String("QObject::connect(watcher, SIGNAL(finished(KDSoapPendingCallWatcher*)),\n"
-                              "                 this, SLOT(") + finishedSlotName + QLatin1String("(KDSoapPendingCallWatcher*)));");
+        code += QLatin1String("QObject::connect(watcher, &KDSoapPendingCallWatcher::finished,\n"
+                              "                 this, &")
+            + newClass.name() + QLatin1String("::")
+            + finishedSlotName + QLatin1String(");");
         asyncFunc.setBody(code);
         newClass.addFunction(asyncFunc);
     }
 }
 
 // Generate signals and the result slot, for async calls
-void Converter::convertClientOutputMessage(const Operation &operation,
-        const Binding &binding, KODE::Class &newClass)
+void Converter::convertClientOutputMessage(const Operation &operation, const Binding &binding, KODE::Class &newClass)
 {
     // result signal
     const QString operationName = lowerlize(operation.name());
@@ -804,7 +839,7 @@ void Converter::convertClientOutputMessage(const Operation &operation,
     // If one output message is used by two input messages, don't define
     // it twice.
     // DF: what if the arguments are different? ...
-    //if ( newClass.hasFunction( respSignal.name() ) )
+    // if ( newClass.hasFunction( respSignal.name() ) )
     //  return;
 
     KODE::Code slotCode;
@@ -823,7 +858,7 @@ void Converter::convertClientOutputMessage(const Operation &operation,
         const Message message = mWSDL.findMessage(operation.output().message());
 
         const Part::List parts = selectedParts(binding, message, operation, false /*output*/);
-        Q_FOREACH (const Part &part, parts) {
+        for (const Part &part : parts) {
             const QString partType = mTypeMap.localType(part.type(), part.element());
             if (partType.isEmpty()) {
                 qWarning("Skipping part '%s'", qPrintable(part.name()));
@@ -856,7 +891,7 @@ void Converter::convertClientOutputMessage(const Operation &operation,
             }
 
             // Forward declaration of element class
-            //newClass.addIncludes( QStringList(), mTypeMap.forwardDeclarationsForElement( part.element() ) );
+            // newClass.addIncludes( QStringList(), mTypeMap.forwardDeclarationsForElement( part.element() ) );
         }
     }
 
@@ -889,7 +924,7 @@ void Converter::createHeader(const SoapBinding::Header &header, KODE::Class &new
         const QString argType = mTypeMap.localInputType(part.type(), part.element());
         const QString methodSig = methodName + QLatin1Char('(') + argType + QLatin1Char(')');
         if (mHeaderMethods.contains(methodSig)) {
-            return;    // already have it (testcase: Services.wsdl)
+            return; // already have it (testcase: Services.wsdl)
         }
 
         mHeaderMethods.insert(methodSig);
@@ -945,4 +980,3 @@ void Converter::addJobResultMember(KODE::Class &jobClass, const Part &part, cons
     getter.setBody(gc);
     jobClass.addFunction(getter);
 }
-
