@@ -1,55 +1,52 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LicenseRef-KDAB-KDSoap-AGPL3-Modified OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
+#include "KDSoapServer.h"
+#include "KDSoapServerAuthInterface.h"
+#include "KDSoapServerCustomVerbRequestInterface.h"
+#include "KDSoapServerObjectInterface.h"
+#include "KDSoapServerRawXMLInterface.h"
 #include "KDSoapServerSocket_p.h"
 #include "KDSoapSocketList_p.h"
-#include "KDSoapServerObjectInterface.h"
-#include "KDSoapServerAuthInterface.h"
-#include "KDSoapServerRawXMLInterface.h"
-#include "KDSoapServerCustomVerbRequestInterface.h"
-#include "KDSoapServer.h"
 #include <KDSoapClient/KDSoapMessage.h>
-#include <KDSoapClient/KDSoapNamespaceManager.h>
 #include <KDSoapClient/KDSoapMessageReader_p.h>
 #include <KDSoapClient/KDSoapMessageWriter_p.h>
+#include <KDSoapClient/KDSoapNamespaceManager.h>
 #include <QBuffer>
-#include <QThread>
-#include <QMetaMethod>
-#include <QFile>
 #include <QDir>
+#include <QFile>
 #include <QFileInfo>
+#include <QMetaMethod>
+#include <QThread>
 #include <QVarLengthArray>
 
+static const char s_forbidden[] = "HTTP/1.1 403 Forbidden\r\nContent-Length: 0\r\n\r\n";
+
 KDSoapServerSocket::KDSoapServerSocket(KDSoapSocketList *owner, QObject *serverObject)
 #ifndef QT_NO_SSL
-    : QSslSocket(),
+    : QSslSocket()
+    ,
 #else
-    : QTcpSocket(),
+    : QTcpSocket()
+    ,
 #endif
-      m_owner(owner),
-      m_serverObject(serverObject),
-      m_delayedResponse(false),
-      m_socketEnabled(true),
-      m_receivedData(false),
-      m_useRawXML(false),
-      m_bytesReceived(0),
-      m_chunkStart(0)
+    m_owner(owner)
+    , m_serverObject(serverObject)
+    , m_delayedResponse(false)
+    , m_socketEnabled(true)
+    , m_receivedData(false)
+    , m_useRawXML(false)
+    , m_bytesReceived(0)
+    , m_chunkStart(0)
 {
-    connect(this, SIGNAL(readyRead()),
-            this, SLOT(slotReadyRead()));
-    m_doDebug = qgetenv("KDSOAP_DEBUG").toInt();
+    connect(this, &QIODevice::readyRead, this, &KDSoapServerSocket::slotReadyRead);
+    m_doDebug = qEnvironmentVariableIsSet("KDSOAP_DEBUG");
 }
 
 // The socket is deleted when it emits disconnected() (see KDSoapSocketList::handleIncomingConnection).
@@ -72,11 +69,22 @@ static HeadersMap parseHeaders(const QByteArray &headerData)
         qDebug() << "Malformed HTTP request:" << firstLine;
         return headersMap;
     }
-    const QByteArray& requestType = firstLine.at(0);
-    const QByteArray path = QDir::cleanPath(QString::fromLatin1(firstLine.at(1).constData())).toLatin1();
-    const QByteArray& httpVersion = firstLine.at(2);
+    const QByteArray &requestType = firstLine.at(0);
     headersMap.insert("_requestType", requestType);
-    headersMap.insert("_path", path);
+
+    // Grammar from https://datatracker.ietf.org/doc/html/rfc7230#section-5.3.1
+    //  origin-form    = absolute-path [ "?" query ]
+    // and https://datatracker.ietf.org/doc/html/rfc3986#section-3.3
+    // says the path ends at the first '?' or '#' character
+    const QByteArray arg1 = firstLine.at(1);
+    const int queryPos = arg1.indexOf('?');
+    const QByteArray path = queryPos >= 0 ? arg1.left(queryPos) : arg1;
+    const QByteArray query = queryPos >= 0 ? arg1.mid(queryPos) : QByteArray();
+    // Unfortunately QDir::cleanPath works with QString
+    const QByteArray cleanedPath = QDir::cleanPath(QString::fromUtf8(path)).toUtf8();
+    headersMap.insert("_path", cleanedPath + query);
+
+    const QByteArray &httpVersion = firstLine.at(2);
     headersMap.insert("_httpVersion", httpVersion);
 
     while (!sourceBuffer.atEnd()) {
@@ -87,7 +95,7 @@ static HeadersMap parseHeaders(const QByteArray &headerData)
         }
         const QByteArray header = line.left(pos).toLower(); // RFC2616 section 4.2 "Field names are case-insensitive"
         const QByteArray value = line.mid(pos + 1).trimmed(); // remove space before and \r\n after
-        //qDebug() << "HEADER" << header << "VALUE" << value;
+        // qDebug() << "HEADER" << header << "VALUE" << value;
         headersMap.insert(header, value);
     }
     return headersMap;
@@ -137,7 +145,7 @@ static QByteArray httpResponseHeaders(bool fault, const QByteArray &contentType,
     KDSoapServerObjectInterface *serverObjectInterface = qobject_cast<KDSoapServerObjectInterface *>(serverObject);
     if (serverObjectInterface) {
         const KDSoapServerObjectInterface::HttpResponseHeaderItems &additionalItems = serverObjectInterface->additionalHttpResponseHeaderItems();
-        Q_FOREACH (const KDSoapServerObjectInterface::HttpResponseHeaderItem &headerItem, additionalItems) {
+        for (const KDSoapServerObjectInterface::HttpResponseHeaderItem &headerItem : qAsConst(additionalItems)) {
             httpResponse += headerItem.m_name;
             httpResponse += ": ";
             httpResponse += headerItem.m_value;
@@ -162,7 +170,7 @@ void KDSoapServerSocket::slotReadyRead()
         m_owner->increaseConnectionCount();
     }
 
-    //qDebug() << this << QThread::currentThread() << "slotReadyRead!";
+    // qDebug() << this << QThread::currentThread() << "slotReadyRead!";
 
     QByteArray buf(2048, ' ');
     qint64 nread = -1;
@@ -183,8 +191,8 @@ void KDSoapServerSocket::slotReadyRead()
         QByteArray receivedHttpHeaders, receivedData;
         const bool splitOK = splitHeadersAndData(m_requestBuffer, receivedHttpHeaders, receivedData);
         if (!splitOK) {
-            //qDebug() << "Incomplete SOAP request, wait for more data";
-            //incomplete request, wait for more data
+            // qDebug() << "Incomplete SOAP request, wait for more data";
+            // incomplete request, wait for more data
             return;
         }
         m_httpHeaders = parseHeaders(receivedHttpHeaders);
@@ -212,7 +220,7 @@ void KDSoapServerSocket::slotReadyRead()
 
         const QByteArray contentLength = m_httpHeaders.value("content-length");
         if (m_bytesReceived < contentLength.toInt()) {
-            return;    // incomplete request, wait for more data
+            return; // incomplete request, wait for more data
         }
 
         if (m_useRawXML) {
@@ -221,14 +229,14 @@ void KDSoapServerSocket::slotReadyRead()
             handleRequest(m_httpHeaders, m_requestBuffer);
         }
     } else {
-        //qDebug() << "requestBuffer has " << m_requestBuffer.size() << "bytes, starting at" << m_chunkStart;
+        // qDebug() << "requestBuffer has " << m_requestBuffer.size() << "bytes, starting at" << m_chunkStart;
         while (m_chunkStart >= 0) {
             const int nextEOL = m_requestBuffer.indexOf("\r\n", m_chunkStart);
             if (nextEOL == -1) {
                 return;
             }
             const QByteArray chunkSizeStr = m_requestBuffer.mid(m_chunkStart, nextEOL - m_chunkStart);
-            //qDebug() << m_chunkStart << nextEOL << "chunkSizeStr=" << chunkSizeStr;
+            // qDebug() << m_chunkStart << nextEOL << "chunkSizeStr=" << chunkSizeStr;
             bool ok;
             int chunkSize = chunkSizeStr.toInt(&ok, 16);
             if (!ok) {
@@ -274,12 +282,19 @@ void KDSoapServerSocket::handleRequest(const QMap<QByteArray, QByteArray> &httpH
     const QByteArray requestType = httpHeaders.value("_requestType");
     const QString path = QString::fromLatin1(httpHeaders.value("_path").constData());
 
+    if (!path.startsWith(QLatin1String("/"))) {
+        // denied for security reasons (ex: path starting with "..")
+        write(s_forbidden);
+        return;
+    }
+
     KDSoapServerAuthInterface *serverAuthInterface = qobject_cast<KDSoapServerAuthInterface *>(m_serverObject);
     if (serverAuthInterface) {
         const QByteArray authValue = httpHeaders.value("authorization");
         if (!serverAuthInterface->handleHttpAuth(authValue, path)) {
             // send auth request (Qt supports basic, ntlm and digest)
-            const QByteArray unauthorized = "HTTP/1.1 401 Authorization Required\r\nWWW-Authenticate: Basic realm=\"example\"\r\nContent-Length: 0\r\n\r\n";
+            const QByteArray unauthorized =
+                "HTTP/1.1 401 Authorization Required\r\nWWW-Authenticate: Basic realm=\"example\"\r\nContent-Length: 0\r\n\r\n";
             write(unauthorized);
             return;
         }
@@ -293,8 +308,8 @@ void KDSoapServerSocket::handleRequest(const QMap<QByteArray, QByteArray> &httpH
             return;
         } else {
             qWarning() << "Unknown HTTP request:" << requestType;
-            //handleError(replyMsg, "Client.Data", QString::fromLatin1("Invalid request type '%1', should be GET or POST").arg(QString::fromLatin1(requestType.constData())));
-            //sendReply(0, replyMsg);
+            // handleError(replyMsg, "Client.Data", QString::fromLatin1("Invalid request type '%1', should be GET or
+            // POST").arg(QString::fromLatin1(requestType.constData()))); sendReply(0, replyMsg);
             const QByteArray methodNotAllowed = "HTTP/1.1 405 Method Not Allowed\r\nAllow: GET POST\r\nContent-Length: 0\r\n\r\n";
             write(methodNotAllowed);
             return;
@@ -307,7 +322,8 @@ void KDSoapServerSocket::handleRequest(const QMap<QByteArray, QByteArray> &httpH
 
     KDSoapServerObjectInterface *serverObjectInterface = qobject_cast<KDSoapServerObjectInterface *>(m_serverObject);
     if (!serverObjectInterface) {
-        const QString error = QString::fromLatin1("Server object %1 does not implement KDSoapServerObjectInterface!").arg(QString::fromLatin1(m_serverObject->metaObject()->className()));
+        const QString error = QString::fromLatin1("Server object %1 does not implement KDSoapServerObjectInterface!")
+                                  .arg(QString::fromLatin1(m_serverObject->metaObject()->className()));
         handleError(replyMsg, "Server.ImplementationError", error);
         sendReply(nullptr, replyMsg);
         return;
@@ -330,32 +346,32 @@ void KDSoapServerSocket::handleRequest(const QMap<QByteArray, QByteArray> &httpH
         return;
     }
 
-    //parse message
+    // parse message
     KDSoapMessage requestMsg;
     KDSoapHeaders requestHeaders;
     KDSoapMessageReader reader;
     KDSoapMessageReader::XmlError err = reader.xmlToMessage(receivedData, &requestMsg, &m_messageNamespace, &requestHeaders, KDSoap::SOAP1_1);
     if (err == KDSoapMessageReader::PrematureEndOfDocumentError) {
-        //qDebug() << "Incomplete SOAP message, wait for more data";
+        // qDebug() << "Incomplete SOAP message, wait for more data";
         // This should never happen, since we check for content-size above.
         return;
-    } //TODO handle parse errors?
+    } // TODO handle parse errors?
 
     // check soap version and extract soapAction header
     QByteArray soapAction;
     const QByteArray contentType = httpHeaders.value("content-type");
-    if (contentType.startsWith("text/xml")) { //krazy:exclude=strings
+    if (contentType.startsWith("text/xml")) { // krazy:exclude=strings
         // SOAP 1.1
         soapAction = httpHeaders.value("soapaction");
         // The SOAP standard allows quotation marks around the SoapAction, so we have to get rid of these.
         soapAction = stripQuotes(soapAction);
 
-    } else if (contentType.startsWith("application/soap+xml")) { //krazy:exclude=strings
+    } else if (contentType.startsWith("application/soap+xml")) { // krazy:exclude=strings
         // SOAP 1.2
         // Example: application/soap+xml;charset=utf-8;action=ActionHex
         const QList<QByteArray> parts = contentType.split(';');
-        Q_FOREACH (const QByteArray &part, parts) {
-            if (part.trimmed().startsWith("action=")) { //krazy:exclude=strings
+        for (const QByteArray &part : qAsConst(parts)) {
+            if (part.trimmed().startsWith("action=")) { // krazy:exclude=strings
                 soapAction = stripQuotes(part.mid(part.indexOf('=') + 1));
             }
         }
@@ -381,7 +397,7 @@ bool KDSoapServerSocket::handleWsdlDownload()
     const QString wsdlFile = server->wsdlFile();
     QFile wf(wsdlFile);
     if (wf.open(QIODevice::ReadOnly)) {
-        //qDebug() << "Returning wsdl file contents";
+        // qDebug() << "Returning wsdl file contents";
         const QByteArray responseText = wf.readAll();
         const QByteArray response = httpResponseHeaders(false, "application/xml", responseText.size(), m_serverObject);
         write(response);
@@ -401,8 +417,7 @@ bool KDSoapServerSocket::handleFileDownload(KDSoapServerObjectInterface *serverO
         return true;
     }
     if (!device->open(QIODevice::ReadOnly)) {
-        const QByteArray forbidden = "HTTP/1.1 403 Forbidden\r\nContent-Length: 0\r\n\r\n";
-        write(forbidden);
+        write(s_forbidden);
         delete device;
         return true; // handled!
     }
@@ -415,19 +430,19 @@ bool KDSoapServerSocket::handleFileDownload(KDSoapServerObjectInterface *serverO
     Q_UNUSED(written);
 
     char block[4096] = {0};
-    qint64 totalRead = 0;
+    // qint64 totalRead = 0;
     while (!device->atEnd()) {
         const qint64 in = device->read(block, sizeof(block));
         if (in <= 0) {
             break;
         }
-        totalRead += in;
+        // totalRead += in;
         if (in != write(block, in)) {
-            //error = true;
+            // error = true;
             break;
         }
     }
-    //if (totalRead != device->size()) {
+    // if (totalRead != device->size()) {
     //    // Unable to read from the source.
     //    error = true;
     //}
@@ -439,7 +454,8 @@ bool KDSoapServerSocket::handleFileDownload(KDSoapServerObjectInterface *serverO
 
 void KDSoapServerSocket::writeXML(const QByteArray &xmlResponse, bool isFault)
 {
-    const QByteArray httpHeaders = httpResponseHeaders(isFault, "text/xml", xmlResponse.size(), m_serverObject); // TODO return application/soap+xml;charset=utf-8 instead for SOAP 1.2
+    const QByteArray httpHeaders = httpResponseHeaders(isFault, "text/xml", xmlResponse.size(),
+                                                       m_serverObject); // TODO return application/soap+xml;charset=utf-8 instead for SOAP 1.2
     if (m_doDebug) {
         qDebug() << "KDSoapServerSocket: writing" << httpHeaders << xmlResponse;
     }
@@ -480,10 +496,10 @@ void KDSoapServerSocket::sendReply(KDSoapServerObjectInterface *serverObjectInte
 
     // All done, check if we should log this
     KDSoapServer *server = m_owner->server();
-    const KDSoapServer::LogLevel logLevel = server->logLevel(); // we do this here in order to support dynamic settings changes (at the price of a mutex)
+    const KDSoapServer::LogLevel logLevel =
+        server->logLevel(); // we do this here in order to support dynamic settings changes (at the price of a mutex)
     if (logLevel != KDSoapServer::LogNothing) {
-        if (logLevel == KDSoapServer::LogEveryCall ||
-                (logLevel == KDSoapServer::LogFaults && isFault)) {
+        if (logLevel == KDSoapServer::LogEveryCall || (logLevel == KDSoapServer::LogFaults && isFault)) {
 
             if (isFault) {
                 server->log("FAULT " + m_method.toLatin1() + " -- " + replyMsg.faultAsString().toUtf8() + '\n');
@@ -513,7 +529,8 @@ void KDSoapServerSocket::handleError(KDSoapMessage &replyMsg, const char *errorC
     replyMsg.createFaultMessage(QString::fromLatin1(errorCode), error, soapVersion);
 }
 
-void KDSoapServerSocket::makeCall(KDSoapServerObjectInterface *serverObjectInterface, const KDSoapMessage &requestMsg, KDSoapMessage &replyMsg, const KDSoapHeaders &requestHeaders, const QByteArray &soapAction, const QString &path)
+void KDSoapServerSocket::makeCall(KDSoapServerObjectInterface *serverObjectInterface, const KDSoapMessage &requestMsg, KDSoapMessage &replyMsg,
+                                  const KDSoapHeaders &requestHeaders, const QByteArray &soapAction, const QString &path)
 {
     Q_ASSERT(serverObjectInterface);
 
@@ -535,7 +552,7 @@ void KDSoapServerSocket::makeCall(KDSoapServerObjectInterface *serverObjectInter
             serverObjectInterface->processRequest(requestMsg, replyMsg, soapAction);
         }
         if (serverObjectInterface->hasFault()) {
-            //qDebug() << "Got fault!";
+            // qDebug() << "Got fault!";
             replyMsg.setFault(true);
             serverObjectInterface->storeFaultAttributes(replyMsg);
         }
