@@ -1,27 +1,21 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2021 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 
 #include "httpserver_p.h"
-#include <QNetworkRequest>
-#include <QNetworkReply>
-#include <QNetworkAccessManager>
-#include <QDomDocument>
 #include <QDateTime>
+#include <QDomDocument>
 #include <QEventLoop>
 #include <QFile>
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
+#include <QNetworkRequest>
 #ifndef QT_NO_OPENSSL
 #include <QSslConfiguration>
 #endif
@@ -155,7 +149,7 @@ bool KDSoapUnitTestHelpers::setSslConfiguration()
         qDebug() << "It is valid from" << cert.effectiveDate() << "to" << cert.expiryDate();
         return false;
     }
-    defaultConfig.setCaCertificates({ cert });
+    defaultConfig.setCaCertificates({cert});
     QSslConfiguration::setDefaultConfiguration(defaultConfig);
 
     return true;
@@ -292,7 +286,7 @@ void HttpServerThread::run()
     lock.unlock();
     m_ready.release();
 
-    const bool doDebug = qgetenv("KDSOAP_DEBUG").toInt();
+    const bool doDebug = qEnvironmentVariableIsSet("KDSOAP_DEBUG");
 
     if (doDebug) {
         qDebug() << "HttpServerThread listening on port" << m_port;
@@ -490,13 +484,13 @@ const char *KDSoapUnitTestHelpers::xmlEnvBegin11()
 
 const char *KDSoapUnitTestHelpers::xmlEnvBegin11WithWSAddressing()
 {
-    return  "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
-            "<soap:Envelope"
-            " xmlns:soap=\"http://schemas.xmlsoap.org/soap/envelope/\""
-            " xmlns:soap-enc=\"http://schemas.xmlsoap.org/soap/encoding/\""
-            " xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\""
-            " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
-            " xmlns:wsa=\"http://www.w3.org/2005/08/addressing\"";
+    return "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
+           "<soap:Envelope"
+           " xmlns:soap=\"http://schemas.xmlsoap.org/soap/envelope/\""
+           " xmlns:soap-enc=\"http://schemas.xmlsoap.org/soap/encoding/\""
+           " xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\""
+           " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\""
+           " xmlns:wsa=\"http://www.w3.org/2005/08/addressing\"";
 }
 
 
@@ -527,5 +521,5 @@ const char *KDSoapUnitTestHelpers::xmlEnvEnd()
     return "</soap:Envelope>";
 }
 
-#include "moc_httpserver_p.cpp"
 #include "httpserver_p.moc"
+#include "moc_httpserver_p.cpp"
