@@ -1,27 +1,21 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 
+#include "KDDateTime.h"
 #include "KDSoapClientInterface.h"
 #include "KDSoapMessage.h"
 #include "KDSoapValue.h"
-#include "KDDateTime.h"
-#include "wsdl_DWService.h"
 #include "httpserver_p.h"
-#include <QTest>
+#include "wsdl_DWService.h"
 #include <QDebug>
+#include <QTest>
 
 using namespace KDSoapUnitTestHelpers;
 
@@ -43,16 +37,15 @@ private Q_SLOTS:
         const KDAB::TNS__LoginResponse resp = service.login(loginParams);
 
         // Check what we sent
-        QByteArray expectedRequestXml =
-            QByteArray(xmlEnvBegin11()) +
-            "><soap:Body>"
-            "<n1:Login xmlns:n1=\"http://tempuri.org/\">"
-            "<n1:userName>Foo</n1:userName>"
-            // minoccurs=0, so we don't need this: "<n1:password xsi:nil=\"true\"></n1:password>"
-            "<n1:organization>KDAB</n1:organization>"
-            "</n1:Login>"
-            "</soap:Body>" + xmlEnvEnd()
-            + '\n'; // added by QXmlStreamWriter::writeEndDocument
+        QByteArray expectedRequestXml = QByteArray(xmlEnvBegin11())
+            + "><soap:Body>"
+              "<n1:Login xmlns:n1=\"http://tempuri.org/\">"
+              "<n1:userName>Foo</n1:userName>"
+              // minoccurs=0, so we don't need this: "<n1:password xsi:nil=\"true\"></n1:password>"
+              "<n1:organization>KDAB</n1:organization>"
+              "</n1:Login>"
+              "</soap:Body>"
+            + xmlEnvEnd() + '\n'; // added by QXmlStreamWriter::writeEndDocument
         QVERIFY(xmlBufferCompare(server.receivedData(), expectedRequestXml));
 
         const KDAB::Q1__ClientServiceSession session = resp.loginResult();
@@ -73,28 +66,29 @@ private Q_SLOTS:
         service.logoff(logoffParams);
 
         // Check what we sent
-        QByteArray expectedRequestXml =
-            QByteArray(xmlEnvBegin11()) +
-            "><soap:Body>"
-            "<n1:Logoff xmlns:n1=\"http://tempuri.org/\">"
-            "<n1:clientSession><n2:SessionID xmlns:n2=\"http://schemas.datacontract.org/2004/07/DocuWare.WebServices.GAPIFunctionality.DataContracts\">65a65c1f-2613-47d0-89ec-1c7b1fe34777</n2:SessionID></n1:clientSession>"
-            "</n1:Logoff>"
-            "</soap:Body>" + xmlEnvEnd()
-            + '\n'; // added by QXmlStreamWriter::writeEndDocument
+        QByteArray expectedRequestXml = QByteArray(xmlEnvBegin11())
+            + "><soap:Body>"
+              "<n1:Logoff xmlns:n1=\"http://tempuri.org/\">"
+              "<n1:clientSession><n2:SessionID "
+              "xmlns:n2=\"http://schemas.datacontract.org/2004/07/"
+              "DocuWare.WebServices.GAPIFunctionality.DataContracts\">65a65c1f-2613-47d0-89ec-1c7b1fe34777</n2:SessionID></n1:clientSession>"
+              "</n1:Logoff>"
+              "</soap:Body>"
+            + xmlEnvEnd() + '\n'; // added by QXmlStreamWriter::writeEndDocument
         QVERIFY(xmlBufferCompare(server.receivedData(), expectedRequestXml));
-
     }
 
 private:
     static QByteArray loginResponse()
     {
-        return QByteArray(xmlEnvBegin11()) + " xmlns:dw=\"http://schemas.novell.com/2005/01/GroupWise/groupwise.wsdl\"><soap:Body>"
-               "<dw:LoginResponse>"
-               "<dw:LoginResult><dw:SessionID>65a65c1f-2613-47d0-89ec-1c7b1fe34777</dw:SessionID></dw:LoginResult>"
-               "</dw:LoginResponse>"
-               "</soap:Body>" + xmlEnvEnd();
+        return QByteArray(xmlEnvBegin11())
+            + " xmlns:dw=\"http://schemas.novell.com/2005/01/GroupWise/groupwise.wsdl\"><soap:Body>"
+              "<dw:LoginResponse>"
+              "<dw:LoginResult><dw:SessionID>65a65c1f-2613-47d0-89ec-1c7b1fe34777</dw:SessionID></dw:LoginResult>"
+              "</dw:LoginResponse>"
+              "</soap:Body>"
+            + xmlEnvEnd();
     }
-
 };
 
 QTEST_MAIN(DWServiceTest)
