@@ -1,25 +1,19 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2014-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2014-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 
 
-#include "wsdl_uitapi.h"
 #include "httpserver_p.h"
-#include <QTest>
-#include <QEventLoop>
+#include "wsdl_uitapi.h"
 #include <QDebug>
+#include <QEventLoop>
+#include <QTest>
 
 using namespace KDSoapUnitTestHelpers;
 
@@ -29,13 +23,16 @@ class UitapiRPCTest : public QObject
 
 private Q_SLOTS:
     // Using wsdl-generated code, create a job with an empty response,
-    // check that job emits finnished (https://github.com/KDAB/KDSoap/issues/94)
+    // check that job emits finished (https://github.com/KDAB/KDSoap/issues/94)
     void testEmptyRPCResponse()
     {
         // Prepare response
-        QByteArray responseData = QByteArray(xmlEnvBegin11()) + "><soap:Body>"
-                                  "<ns1:createDirectoryResponse soap:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:ns1=\"https://www.uit.hpc.mil/UITAPIv3/uitapi.jws\"/>"
-                                  " </soap:Body>" + xmlEnvEnd();
+        QByteArray responseData = QByteArray(xmlEnvBegin11())
+            + "><soap:Body>"
+              "<ns1:createDirectoryResponse soap:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\" "
+              "xmlns:ns1=\"https://www.uit.hpc.mil/UITAPIv3/uitapi.jws\"/>"
+              " </soap:Body>"
+            + xmlEnvEnd();
         HttpServerThread server(responseData, HttpServerThread::Public);
 
         UitapiService service;
@@ -48,7 +45,7 @@ private Q_SLOTS:
         job->setDirectory("dir");
 
         QEventLoop loop;
-        QObject::connect(job, SIGNAL(finished(KDSoapJob*)), &loop, SLOT(quit()));
+        QObject::connect(job, &CreateDirectoryJob::finished, &loop, &QEventLoop::quit);
         job->start();
         loop.exec();
     }
@@ -57,9 +54,13 @@ private Q_SLOTS:
     void testReturnRPCResponse()
     {
         // Prepare response
-        QByteArray responseData = QByteArray(xmlEnvBegin11()) + "><soap:Body>"
-            "<ns1:getAllocationInfoResponse soap:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:ns1=\"https://www.uit.hpc.mil/UITAPIv3/uitapi.jws\"><ns1:getAllocationInfoReturn>The response</ns1:getAllocationInfoReturn></ns1:getAllocationInfoResponse>"
-                                              " </soap:Body>" + xmlEnvEnd();
+        QByteArray responseData = QByteArray(xmlEnvBegin11())
+            + "><soap:Body>"
+              "<ns1:getAllocationInfoResponse soap:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\" "
+              "xmlns:ns1=\"https://www.uit.hpc.mil/UITAPIv3/uitapi.jws\"><ns1:getAllocationInfoReturn>The "
+              "response</ns1:getAllocationInfoReturn></ns1:getAllocationInfoResponse>"
+              " </soap:Body>"
+            + xmlEnvEnd();
         HttpServerThread server(responseData, HttpServerThread::Public);
 
         UitapiService service;
@@ -71,7 +72,7 @@ private Q_SLOTS:
         job->setUsername("me");
 
         QEventLoop loop;
-        QObject::connect(job, SIGNAL(finished(KDSoapJob*)), &loop, SLOT(quit()));
+        QObject::connect(job, &GetAllocationInfoJob::finished, &loop, &QEventLoop::quit);
         job->start();
         loop.exec();
 
@@ -83,6 +84,3 @@ private Q_SLOTS:
 QTEST_MAIN(UitapiRPCTest)
 
 #include "test_uitapi.moc"
-
-
-
