@@ -1,16 +1,10 @@
 /****************************************************************************
 **
-** This file is part of the KD Soap library.
+** This file is part of the KD Soap project.
 **
-** SPDX-FileCopyrightText: 2010-2020 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+** SPDX-FileCopyrightText: 2010-2022 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 **
-** SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDAB-KDSoap OR LicenseRef-KDAB-KDSoap-US
-**
-** Licensees holding valid commercial KD Soap licenses may use this file in
-** accordance with the KD Soap Commercial License Agreement provided with
-** the Software.
-**
-** Contact info@kdab.com if any conditions of this licensing are not clear to you.
+** SPDX-License-Identifier: MIT
 **
 ****************************************************************************/
 
@@ -18,19 +12,19 @@
 #include "wsdl_sayhello.h"
 
 #include "httpserver_p.h"
-#include <QTest>
-#include <QEventLoop>
-#include <QDebug>
 #include <KDSoapClientInterface.h>
 #include <KDSoapMessage.h>
-#include <KDSoapServer.h>
 #include <KDSoapNamespaceManager.h>
-#include <KDSoapPendingCallWatcher.h>
 #include <KDSoapPendingCall.h>
+#include <KDSoapPendingCallWatcher.h>
+#include <KDSoapServer.h>
+#include <QDebug>
+#include <QEventLoop>
 #include <QNetworkAccessManager>
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 #include <QSignalSpy>
+#include <QTest>
 
 using namespace KDSoapUnitTestHelpers;
 
@@ -51,6 +45,7 @@ public:
     {
         return m_receivedLastName;
     }
+
 private:
     QString m_receivedFirstName;
     QString m_receivedLastName;
@@ -60,7 +55,9 @@ class HelloServer : public KDSoapServer
 {
     Q_OBJECT
 public:
-    HelloServer() : KDSoapServer(), m_lastServerObject(0)
+    HelloServer()
+        : KDSoapServer()
+        , m_lastServerObject(0)
     {
         setPath(QLatin1String("/hello"));
     }
@@ -73,6 +70,7 @@ public:
     {
         return m_lastServerObject;
     }
+
 private:
     HelloServerObject *m_lastServerObject;
 };
@@ -82,12 +80,15 @@ class RpcExampleServerObject : public RpcExampleServerBase
 public:
     RpcExampleServerObject()
         : m_heartbeatCalled(false)
-    {}
+    {
+    }
     virtual RPCEXAMPLE__ListKeysResult listKeys(const RPCEXAMPLE__ListKeysParams &params) override
     {
         Q_UNUSED(params)
         RPCEXAMPLE__ListKeysResult result;
-        result.setKeys(QStringList() << "test1" << "test2" << "test3");
+        result.setKeys(QStringList() << "test1"
+                                     << "test2"
+                                     << "test3");
         return result;
     }
 
@@ -163,6 +164,7 @@ public:
     {
         return m_heartbeatCalled;
     }
+
 private:
     bool m_heartbeatCalled;
 };
@@ -171,7 +173,9 @@ class RpcExampleServer : public KDSoapServer
 {
     Q_OBJECT
 public:
-    RpcExampleServer() : KDSoapServer(), m_lastServerObject(0)
+    RpcExampleServer()
+        : KDSoapServer()
+        , m_lastServerObject(0)
     {
         setPath(QLatin1String("/rpcexample"));
     }
@@ -184,6 +188,7 @@ public:
     {
         return m_lastServerObject;
     }
+
 private:
     RpcExampleServerObject *m_lastServerObject;
 };
@@ -193,17 +198,17 @@ class RPCServerTest : public QObject
     Q_OBJECT
 
 private:
-
     static QByteArray expectedHelloRequest() // http://oreilly.com/catalog/webservess/chapter/ch06.html
     {
-        return QByteArray(xmlEnvBegin11()) + ">"
-               "<soap:Body>"
-               "<n1:sayHello xmlns:n1=\"urn:examples:helloservice\">"
-               "<firstName xsi:type=\"xsd:string\">Hello</firstName>"
-               "<lastName xsi:type=\"xsd:string\">World</lastName>"
-               "</n1:sayHello>"
-               "</soap:Body>" + xmlEnvEnd()
-               + '\n'; // added by QXmlStreamWriter::writeEndDocument
+        return QByteArray(xmlEnvBegin11())
+            + ">"
+              "<soap:Body>"
+              "<n1:sayHello xmlns:n1=\"urn:examples:helloservice\">"
+              "<firstName xsi:type=\"xsd:string\">Hello</firstName>"
+              "<lastName xsi:type=\"xsd:string\">World</lastName>"
+              "</n1:sayHello>"
+              "</soap:Body>"
+            + xmlEnvEnd() + '\n'; // added by QXmlStreamWriter::writeEndDocument
     }
     static QByteArray helloResponse()
     {
@@ -224,21 +229,24 @@ private:
 
     static QByteArray expectedListKeysRequest()
     {
-        return QByteArray(xmlEnvBegin12()) + ">"
-               "<soap:Body>"
-               "<n1:listKeys xmlns:n1=\"urn:RpcExample\">"
-               "<params xsi:type=\"n1:listKeysParams\">"
-               "<module xsi:type=\"xsd:string\">Firefox</module>"
-               "<base xsi:type=\"xsd:string\"></base>"
-               "</params>"
-               "</n1:listKeys>"
-               "</soap:Body>" + xmlEnvEnd()
-               + '\n'; // added by QXmlStreamWriter::writeEndDocument
+        return QByteArray(xmlEnvBegin12())
+            + ">"
+              "<soap:Body>"
+              "<n1:listKeys xmlns:n1=\"urn:RpcExample\">"
+              "<params xsi:type=\"n1:listKeysParams\">"
+              "<module xsi:type=\"xsd:string\">Firefox</module>"
+              "<base xsi:type=\"xsd:string\"/>"
+              "</params>"
+              "</n1:listKeys>"
+              "</soap:Body>"
+            + xmlEnvEnd() + '\n'; // added by QXmlStreamWriter::writeEndDocument
     }
     static QByteArray listKeysResponse()
     {
         return "<?xml version=\"1.0\" encoding=\"UTF-8\"?>"
-               "<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://www.w3.org/2003/05/soap-envelope\" xmlns:SOAP-ENC=\"http://www.w3.org/2003/05/soap-encoding\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:RpcExample=\"urn:RpcExample\">"
+               "<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://www.w3.org/2003/05/soap-envelope\" "
+               "xmlns:SOAP-ENC=\"http://www.w3.org/2003/05/soap-encoding\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
+               "xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:RpcExample=\"urn:RpcExample\">"
                "<SOAP-ENV:Body>"
                "<RpcExample:listKeysResponse SOAP-ENV:encodingStyle=\"http://www.w3.org/2003/05/soap-encoding\">"
                "<result>"
@@ -311,14 +319,16 @@ private Q_SLOTS:
         RPCEXAMPLE__HeartbeatParams params;
         KDSoapMessage message;
         message.setUse(KDSoapMessage::EncodedUse);
-        KDSoapValue _valueParams(params.serialize(QString::fromLatin1("params")));// /Users/mbroadst/Development/devonit/echosupport/KDSoap/kdwsdl2cpp/src/converter_complextype.cpp:209
+        KDSoapValue _valueParams(params.serialize(
+            QString::fromLatin1("params"))); // /Users/mbroadst/Development/devonit/echosupport/KDSoap/kdwsdl2cpp/src/converter_complextype.cpp:209
         _valueParams.setNamespaceUri(QString::fromLatin1("urn:RpcExample"));
-        message.childValues().append(_valueParams);// /Users/mbroadst/Development/devonit/echosupport/KDSoap/kdwsdl2cpp/src/converter_complextype.cpp:223
+        message.childValues().append(
+            _valueParams); // /Users/mbroadst/Development/devonit/echosupport/KDSoap/kdwsdl2cpp/src/converter_complextype.cpp:223
 
         QEventLoop eventLoop;
         KDSoapPendingCall pendingCall = service.clientInterface()->asyncCall(QLatin1String("heartbeat"), message);
         KDSoapPendingCallWatcher *watcher = new KDSoapPendingCallWatcher(pendingCall, this);
-        connect(watcher, SIGNAL(finished(KDSoapPendingCallWatcher*)), &eventLoop, SLOT(quit()));
+        connect(watcher, &KDSoapPendingCallWatcher::finished, &eventLoop, &QEventLoop::quit);
         eventLoop.exec();
 
         KDSoapMessage returnMessage = watcher->returnMessage();
@@ -338,16 +348,16 @@ private Q_SLOTS:
         RpcExample service;
         service.setEndPoint(server->endPoint());
 
-        QSignalSpy spy(&service, SIGNAL(heartbeatDone()));
+        QSignalSpy spy(&service, &RpcExample::heartbeatDone);
         QVERIFY(spy.isValid());
 
         qRegisterMetaType<KDSoapMessage>("KDSoapMessage");
-        QSignalSpy errorSpy(&service, SIGNAL(heartbeatError(KDSoapMessage)));
+        QSignalSpy errorSpy(&service, &RpcExample::heartbeatError);
         QVERIFY(errorSpy.isValid());
 
         // Qt5: use spy.wait() instead.
         QEventLoop eventLoop;
-        connect(&service, SIGNAL(heartbeatDone()), &eventLoop, SLOT(quit()));
+        connect(&service, &RpcExample::heartbeatDone, &eventLoop, &QEventLoop::quit);
         RPCEXAMPLE__HeartbeatParams params;
         service.asyncHeartbeat(params);
         eventLoop.exec();
